LiveBarcodeScannerController class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showBarCodeScanner(BuildContext context, ValueChanged<String> onResult, VoidCallback onFailed) → void
startListening({required ValueChanged<String> onScanned, required VoidCallback onFailed}) Future<void>
startScan() Future<void>
stopScan() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited